import { HttpClient } from '@wix/sdk-types';
import { BulkDeleteSiteResponse, BulkDeleteSiteResponseNonNullableFields, DuplicateSiteOptions, DuplicateSiteResponse, DuplicateSiteResponseNonNullableFields } from './site-actions-v1-site-actions-site-actions.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function publishSite(httpClient: HttpClient): PublishSiteSignature;
interface PublishSiteSignature {
    /**
     * Publishes a site.
     *
     * Publishing a site makes any changes previously saved on the site available on the internet.
     * After publishing, changes to your site appear in the [site's history](https://support.wix.com/en/article/viewing-and-managing-your-site-history).
     *
     * When you call this API, you must pass a header called `wix-site-id` whose value is the ID of the site you want to publish. Learn more about
     * working with [API keys and site IDs](https://dev.wix.com/docs/rest/articles/getting-started/api-keys#create-and-use-api-keys).
     *
     * >**Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
     */
    (): Promise<void>;
}
export declare function duplicateSite(httpClient: HttpClient): DuplicateSiteSignature;
interface DuplicateSiteSignature {
    /**
     * Duplicates a site with a new site name.
     *
     * > **Note:** When you duplicate a site, some business-related content such as store orders, contacts, invoices, and 3rd-party app settings are not be included.
     * > The duplicated site won’t have a domain or any Premium capabilities.
     *
     * Any installed apps that can be used only on sites with a Premium Plan, will be copied to the duplicated site and
     * will appear unactivated. Once the site is upgraded, the app will be available for use.
     *
     * > **Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
     * @param - ID of the site to duplicated.
     */
    (sourceSiteId: string, options: DuplicateSiteOptions): Promise<DuplicateSiteResponse & DuplicateSiteResponseNonNullableFields>;
}
export declare function bulkDeleteSite(httpClient: HttpClient): BulkDeleteSiteSignature;
interface BulkDeleteSiteSignature {
    /**
     * This endpoint enables you to delete multiple sites.
     *
     * This is not a permanent delete. Sites are moved to the trash bin and can be restored through site collaborators.
     *
     * Learn more about [deleting multiple sites](https://support.wix.com/en/article/moving-a-site-to-trash).
     *
     * > **Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
     * @param - Site IDs.
     *
     * Min: 1 site ID <br>
     * Max: 20 site IDs
     */
    (ids: string[]): Promise<BulkDeleteSiteResponse & BulkDeleteSiteResponseNonNullableFields>;
}
export { ApplicationError, BulkActionMetadata, BulkDeleteSiteRequest, BulkDeleteSiteResponse, BulkDeleteSiteResponseNonNullableFields, BulkSiteResult, DeployStandalonePagesRequest, DeployStandalonePagesResponse, DuplicateSiteOptions, DuplicateSiteRequest, DuplicateSiteResponse, DuplicateSiteResponseNonNullableFields, EmptyEntity, ItemMetadata, PublishSiteRequest, PublishSiteResponse, } from './site-actions-v1-site-actions-site-actions.universal.js';
