"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.bulkDeleteSite = exports.duplicateSite = exports.publishSite = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixSiteActionsV1SiteActions = __importStar(require("./site-actions-v1-site-actions-site-actions.http.js"));
/**
 * Publishes a site.
 *
 * Publishing a site makes any changes previously saved on the site available on the internet.
 * After publishing, changes to your site appear in the [site's history](https://support.wix.com/en/article/viewing-and-managing-your-site-history).
 *
 * When you call this API, you must pass a header called `wix-site-id` whose value is the ID of the site you want to publish. Learn more about
 * working with [API keys and site IDs](https://dev.wix.com/docs/rest/articles/getting-started/api-keys#create-and-use-api-keys).
 *
 * >**Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 * @public
 * @permissionId METASITE.UPDATE
 * @fqn wix.site.v1.SitePublisher.PublishSite
 */
async function publishSite() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({});
    const reqOpts = ambassadorWixSiteActionsV1SiteActions.publishSite(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {},
            singleArgumentUnchanged: false,
        }, []);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.publishSite = publishSite;
/**
 * Duplicates a site with a new site name.
 *
 * > **Note:** When you duplicate a site, some business-related content such as store orders, contacts, invoices, and 3rd-party app settings are not be included.
 * > The duplicated site won’t have a domain or any Premium capabilities.
 *
 * Any installed apps that can be used only on sites with a Premium Plan, will be copied to the duplicated site and
 * will appear unactivated. Once the site is upgraded, the app will be available for use.
 *
 * > **Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 * @param sourceSiteId - ID of the site to duplicated.
 * @public
 * @documentationMaturity preview
 * @requiredField options
 * @requiredField options.siteDisplayName
 * @requiredField sourceSiteId
 * @permissionId my-account.duplicate-site
 * @fqn com.wix.site.actions.SiteActionsService.DuplicateSite
 */
async function duplicateSite(sourceSiteId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        sourceSiteId: sourceSiteId,
        siteDisplayName: options?.siteDisplayName,
    });
    const reqOpts = ambassadorWixSiteActionsV1SiteActions.duplicateSite(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                sourceSiteId: '$[0]',
                siteDisplayName: '$[1].siteDisplayName',
            },
            singleArgumentUnchanged: false,
        }, ['sourceSiteId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.duplicateSite = duplicateSite;
/**
 * This endpoint enables you to delete multiple sites.
 *
 * This is not a permanent delete. Sites are moved to the trash bin and can be restored through site collaborators.
 *
 * Learn more about [deleting multiple sites](https://support.wix.com/en/article/moving-a-site-to-trash).
 *
 * > **Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 * @param ids - Site IDs.
 *
 * Min: 1 site ID <br>
 * Max: 20 site IDs
 * @public
 * @documentationMaturity preview
 * @requiredField ids
 * @permissionId my-account.delete-site
 * @fqn com.wix.site.actions.SiteActionsService.BulkDeleteSite
 */
async function bulkDeleteSite(ids) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ ids: ids });
    const reqOpts = ambassadorWixSiteActionsV1SiteActions.bulkDeleteSite(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { ids: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['ids']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.bulkDeleteSite = bulkDeleteSite;
//# sourceMappingURL=site-actions-v1-site-actions-site-actions.universal.js.map