/**
 * A package is group of instances of Wix services that a reseller offers to a
 * customer as part of a single transaction.
 */
export interface EmptyEntity {
}
export interface PublishSiteRequest {
}
export interface PublishSiteResponse {
}
export interface DeployStandalonePagesRequest {
}
export interface DeployStandalonePagesResponse {
}
export interface DuplicateSiteRequest {
    /**
     * ID of the site to duplicated.
     * @format GUID
     */
    sourceSiteId: string;
    /**
     * Display name for the new site.
     * @minLength 1
     * @maxLength 40
     */
    siteDisplayName: string;
}
export interface DuplicateSiteResponse {
    /**
     * ID of the new site.
     * @format GUID
     */
    newSiteId?: string;
}
export interface BulkDeleteSiteRequest {
    /**
     * Site IDs.
     *
     * Min: 1 site ID <br>
     * Max: 20 site IDs
     * @format GUID
     * @minSize 1
     * @maxSize 20
     */
    ids: string[];
}
export interface BulkDeleteSiteResponse {
    /** List of deletion results. */
    results?: BulkSiteResult[];
    /** Summary of deletion data. */
    bulkActionMetadata?: BulkActionMetadata;
}
export interface BulkSiteResult {
    /** Result of deletion request per site describing the success or failure of each deletion. */
    itemMetadata?: ItemMetadata;
}
export interface ItemMetadata {
    /** Site ID. */
    _id?: string | null;
    /** Index of the site in the request array. Allows for correlation between request and response. */
    originalIndex?: number;
    /** Whether the requested action was successful for the site. When `false`, the action failed and an `error` object is populated. */
    success?: boolean;
    /** Details about the error. */
    error?: ApplicationError;
}
export interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of error. */
    description?: string;
}
export interface BulkActionMetadata {
    /** Number of sites that were deleted successfully. */
    totalSuccesses?: number;
    /** Number of sites that were not deleted successfully. */
    totalFailures?: number;
}
export interface DuplicateSiteResponseNonNullableFields {
    newSiteId: string;
}
interface ApplicationErrorNonNullableFields {
    code: string;
    description: string;
}
interface ItemMetadataNonNullableFields {
    originalIndex: number;
    success: boolean;
    error?: ApplicationErrorNonNullableFields;
}
interface BulkSiteResultNonNullableFields {
    itemMetadata?: ItemMetadataNonNullableFields;
}
interface BulkActionMetadataNonNullableFields {
    totalSuccesses: number;
    totalFailures: number;
}
export interface BulkDeleteSiteResponseNonNullableFields {
    results: BulkSiteResultNonNullableFields[];
    bulkActionMetadata?: BulkActionMetadataNonNullableFields;
}
/**
 * Publishes a site.
 *
 * Publishing a site makes any changes previously saved on the site available on the internet.
 * After publishing, changes to your site appear in the [site's history](https://support.wix.com/en/article/viewing-and-managing-your-site-history).
 *
 * When you call this API, you must pass a header called `wix-site-id` whose value is the ID of the site you want to publish. Learn more about
 * working with [API keys and site IDs](https://dev.wix.com/docs/rest/articles/getting-started/api-keys#create-and-use-api-keys).
 *
 * >**Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 * @public
 * @permissionId METASITE.UPDATE
 * @fqn wix.site.v1.SitePublisher.PublishSite
 */
export declare function publishSite(): Promise<void>;
/**
 * Duplicates a site with a new site name.
 *
 * > **Note:** When you duplicate a site, some business-related content such as store orders, contacts, invoices, and 3rd-party app settings are not be included.
 * > The duplicated site won’t have a domain or any Premium capabilities.
 *
 * Any installed apps that can be used only on sites with a Premium Plan, will be copied to the duplicated site and
 * will appear unactivated. Once the site is upgraded, the app will be available for use.
 *
 * > **Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 * @param sourceSiteId - ID of the site to duplicated.
 * @public
 * @documentationMaturity preview
 * @requiredField options
 * @requiredField options.siteDisplayName
 * @requiredField sourceSiteId
 * @permissionId my-account.duplicate-site
 * @fqn com.wix.site.actions.SiteActionsService.DuplicateSite
 */
export declare function duplicateSite(sourceSiteId: string, options: DuplicateSiteOptions): Promise<DuplicateSiteResponse & DuplicateSiteResponseNonNullableFields>;
export interface DuplicateSiteOptions {
    /**
     * Display name for the new site.
     * @minLength 1
     * @maxLength 40
     */
    siteDisplayName: string;
}
/**
 * This endpoint enables you to delete multiple sites.
 *
 * This is not a permanent delete. Sites are moved to the trash bin and can be restored through site collaborators.
 *
 * Learn more about [deleting multiple sites](https://support.wix.com/en/article/moving-a-site-to-trash).
 *
 * > **Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 * @param ids - Site IDs.
 *
 * Min: 1 site ID <br>
 * Max: 20 site IDs
 * @public
 * @documentationMaturity preview
 * @requiredField ids
 * @permissionId my-account.delete-site
 * @fqn com.wix.site.actions.SiteActionsService.BulkDeleteSite
 */
export declare function bulkDeleteSite(ids: string[]): Promise<BulkDeleteSiteResponse & BulkDeleteSiteResponseNonNullableFields>;
export {};
