import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Publishes a site.
 *
 * Publishing a site makes any changes previously saved on the site available on the internet.
 * After publishing, changes to your site appear in the [site's history](https://support.wix.com/en/article/viewing-and-managing-your-site-history).
 *
 * When you call this API, you must pass a header called `wix-site-id` whose value is the ID of the site you want to publish. Learn more about
 * working with [API keys and site IDs](https://dev.wix.com/docs/rest/articles/getting-started/api-keys#create-and-use-api-keys).
 *
 * >**Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 */
export declare function publishSite(payload: object): RequestOptionsFactory<any>;
/**
 * Duplicates a site with a new site name.
 *
 * > **Note:** When you duplicate a site, some business-related content such as store orders, contacts, invoices, and 3rd-party app settings are not be included.
 * > The duplicated site won’t have a domain or any Premium capabilities.
 *
 * Any installed apps that can be used only on sites with a Premium Plan, will be copied to the duplicated site and
 * will appear unactivated. Once the site is upgraded, the app will be available for use.
 *
 * > **Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 */
export declare function duplicateSite(payload: object): RequestOptionsFactory<any>;
/**
 * This endpoint enables you to delete multiple sites.
 *
 * This is not a permanent delete. Sites are moved to the trash bin and can be restored through site collaborators.
 *
 * Learn more about [deleting multiple sites](https://support.wix.com/en/article/moving-a-site-to-trash).
 *
 * > **Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 */
export declare function bulkDeleteSite(payload: object): RequestOptionsFactory<any>;
