"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bulkDeleteSite = exports.duplicateSite = exports.publishSite = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
function resolveComWixSiteActionsSiteActionsServiceUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/_api/site-actions',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/site-actions',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/site-actions',
                destPath: '',
            },
        ],
    };
    return (0, rest_modules_1.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
function resolveWixSiteV1SitePublisherUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/_api/site-publisher',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/site-publisher',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/site-publisher',
                destPath: '',
            },
        ],
    };
    return (0, rest_modules_1.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_site-actions_site-actions';
/**
 * Publishes a site.
 *
 * Publishing a site makes any changes previously saved on the site available on the internet.
 * After publishing, changes to your site appear in the [site's history](https://support.wix.com/en/article/viewing-and-managing-your-site-history).
 *
 * When you call this API, you must pass a header called `wix-site-id` whose value is the ID of the site you want to publish. Learn more about
 * working with [API keys and site IDs](https://dev.wix.com/docs/rest/articles/getting-started/api-keys#create-and-use-api-keys).
 *
 * >**Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 */
function publishSite(payload) {
    function __publishSite({ host }) {
        const metadata = {
            entityFqdn: 'wix.site_actions.v1.site_actions',
            method: 'POST',
            methodFqn: 'wix.site.v1.SitePublisher.PublishSite',
            packageName: PACKAGE_NAME,
            url: resolveWixSiteV1SitePublisherUrl({
                protoPath: '/v1/site/publish',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __publishSite;
}
exports.publishSite = publishSite;
/**
 * Duplicates a site with a new site name.
 *
 * > **Note:** When you duplicate a site, some business-related content such as store orders, contacts, invoices, and 3rd-party app settings are not be included.
 * > The duplicated site won’t have a domain or any Premium capabilities.
 *
 * Any installed apps that can be used only on sites with a Premium Plan, will be copied to the duplicated site and
 * will appear unactivated. Once the site is upgraded, the app will be available for use.
 *
 * > **Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 */
function duplicateSite(payload) {
    function __duplicateSite({ host }) {
        const metadata = {
            entityFqdn: 'wix.site_actions.v1.site_actions',
            method: 'POST',
            methodFqn: 'com.wix.site.actions.SiteActionsService.DuplicateSite',
            packageName: PACKAGE_NAME,
            url: resolveComWixSiteActionsSiteActionsServiceUrl({
                protoPath: '/v1/sites/duplicate',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __duplicateSite;
}
exports.duplicateSite = duplicateSite;
/**
 * This endpoint enables you to delete multiple sites.
 *
 * This is not a permanent delete. Sites are moved to the trash bin and can be restored through site collaborators.
 *
 * Learn more about [deleting multiple sites](https://support.wix.com/en/article/moving-a-site-to-trash).
 *
 * > **Important:** This call requires an account level API key and cannot be authenticated with the standard authorization header.
 */
function bulkDeleteSite(payload) {
    function __bulkDeleteSite({ host }) {
        const metadata = {
            entityFqdn: 'wix.site_actions.v1.site_actions',
            method: 'POST',
            methodFqn: 'com.wix.site.actions.SiteActionsService.BulkDeleteSite',
            packageName: PACKAGE_NAME,
            url: resolveComWixSiteActionsSiteActionsServiceUrl({
                protoPath: '/v1/bulk/sites/delete',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __bulkDeleteSite;
}
exports.bulkDeleteSite = bulkDeleteSite;
//# sourceMappingURL=site-actions-v1-site-actions-site-actions.http.js.map